// src/schemas.ts
import { z } from "zod";
var searchSchema = z.boolean().or(
  z.strictObject({
    /**
     * Whether to index code blocks
     * @default true
     */
    codeblocks: z.boolean(),
    /**
     * A filter function to filter out files from indexing, and return the
     * index file key, or null to skip indexing.
     * A site can have multiple indexes, by default they're separated by
     * locales as multiple index files.
     */
    indexKey: z.custom().optional()
  })
);
var nextraConfigSchema = z.strictObject({
  themeConfig: z.string(),
  defaultShowCopyCode: z.boolean(),
  search: searchSchema,
  staticImage: z.boolean(),
  readingTime: z.boolean(),
  latex: z.boolean(),
  codeHighlight: z.boolean(),
  /**
   * A function to modify the code of compiled MDX pages.
   * @experimental
   */
  transform: z.custom(),
  /**
   * A function to modify the `pageOpts` prop passed to theme layouts.
   * @experimental
   */
  transformPageOpts: z.custom(),
  mdxOptions: z.strictObject({
    rehypePlugins: z.custom(),
    remarkPlugins: z.custom(),
    format: z.enum(["detect", "mdx", "md"]),
    rehypePrettyCodeOptions: z.custom()
  })
}).deepPartial().extend({ theme: z.string() });
var pageThemeSchema = z.strictObject({
  breadcrumb: z.boolean(),
  collapsed: z.boolean(),
  footer: z.boolean(),
  layout: z.enum(["default", "full", "raw"]),
  navbar: z.boolean(),
  pagination: z.boolean(),
  sidebar: z.boolean(),
  timestamp: z.boolean(),
  toc: z.boolean(),
  typesetting: z.enum(["default", "article"])
});
var displaySchema = z.enum(["normal", "hidden", "children"]);
var titleSchema = z.string();
var linkItemSchema = z.strictObject({
  href: z.string(),
  newWindow: z.boolean(),
  title: titleSchema
});
var menuItemSchema = z.strictObject({
  display: displaySchema.optional(),
  items: z.record(linkItemSchema.partial({ href: true, newWindow: true })),
  title: titleSchema,
  type: z.literal("menu")
});
var separatorItemSchema = z.strictObject({
  title: titleSchema,
  type: z.literal("separator")
});
var itemSchema = linkItemSchema.extend({
  display: displaySchema,
  theme: pageThemeSchema,
  title: titleSchema,
  type: z.enum(["page", "doc"])
}).deepPartial();
var metaSchema = z.string().or(menuItemSchema).or(separatorItemSchema).or(itemSchema);
export {
  displaySchema,
  menuItemSchema,
  metaSchema,
  nextraConfigSchema,
  pageThemeSchema,
  searchSchema
};
