// src/setup-page.ts
import get from "lodash.get";
import { NEXTRA_INTERNAL } from "./constants.mjs";
import NextraLayout from "./layout";
import { normalizePageRoute, pageTitleFromFilename } from "./utils.mjs";
function isFolder(value) {
  return !!value && typeof value === "object" && value.type === "folder";
}
function normalizeMetaData(obj) {
  return Object.fromEntries(
    Object.entries(obj).map(([key, value]) => {
      if (isFolder(value)) {
        const keyWithoutSlash = key.replace("/", "");
        return [
          keyWithoutSlash,
          value.title || pageTitleFromFilename(keyWithoutSlash)
        ];
      }
      return [key, value || pageTitleFromFilename(key)];
    })
  );
}
function collectCatchAllRoutes(parent, meta, isRootFolder = true) {
  if (isRootFolder) {
    collectCatchAllRoutes(
      parent,
      {
        kind: "Meta",
        data: meta.data
      },
      false
    );
    meta.data = normalizeMetaData(meta.data);
    return;
  }
  for (const [key, value] of Object.entries(meta.data)) {
    if (!isFolder(value)) {
      if (key === "*") {
        continue;
      }
      parent.children.push({
        kind: "MdxPage",
        name: key,
        route: normalizePageRoute(parent.route, key)
      });
      continue;
    }
    const routeWithoutSlashes = key.replace("/", "");
    const newParent = {
      kind: "Folder",
      name: routeWithoutSlashes,
      route: `${parent.route}/${routeWithoutSlashes}`,
      children: [
        {
          kind: "Meta",
          data: normalizeMetaData(value.items)
        }
      ]
    };
    parent.children.push(newParent);
    collectCatchAllRoutes(
      newParent,
      {
        kind: "Meta",
        data: value.items
      },
      false
    );
  }
}
var cachedResolvedPageMap;
function setupNextraPage({
  pageOpts,
  MDXContent,
  hot,
  pageOptsChecksum,
  dynamicMetaModules = [],
  route
}) {
  if (typeof window === "undefined") {
    globalThis.__nextra_resolvePageMap = async () => {
      if (process.env.NODE_ENV === "production" && cachedResolvedPageMap) {
        return cachedResolvedPageMap;
      }
      const clonedPageMap = structuredClone(__nextra_internal__.pageMap);
      for (const [
        metaFunction,
        { metaObjectKeyPath, metaParentKeyPath }
      ] of dynamicMetaModules) {
        const metaData = await metaFunction();
        const meta = get(clonedPageMap, metaObjectKeyPath);
        meta.data = metaData;
        const parent = get(clonedPageMap, metaParentKeyPath);
        collectCatchAllRoutes(parent, meta);
      }
      return cachedResolvedPageMap = clonedPageMap;
    };
  }
  const __nextra_internal__ = globalThis[NEXTRA_INTERNAL];
  __nextra_internal__.route = route;
  __nextra_internal__.pageMap = pageOpts.pageMap;
  pageOpts.frontMatter || (pageOpts.frontMatter = {});
  __nextra_internal__.context[route] = {
    Content: MDXContent,
    pageOpts
  };
  if (process.env.NODE_ENV !== "production" && hot) {
    __nextra_internal__.refreshListeners || (__nextra_internal__.refreshListeners = /* @__PURE__ */ Object.create(null));
    const checksum = pageOptsChecksum;
    hot.data || (hot.data = /* @__PURE__ */ Object.create(null));
    if (hot.data.prevPageOptsChecksum !== checksum) {
      const listeners = __nextra_internal__.refreshListeners[route] || [];
      for (const listener of listeners) {
        listener();
      }
    }
    hot.dispose((data) => {
      data.prevPageOptsChecksum = checksum;
    });
  }
  return NextraLayout;
}
export {
  collectCatchAllRoutes,
  setupNextraPage
};
