import { GrayMatterFile } from 'gray-matter';
import { Heading as Heading$1 } from 'mdast';
import { NextConfig } from 'next';
import { ReactNode, FC } from 'react';
import { z } from 'zod';
import { NEXTRA_INTERNAL, META_FILENAME, MARKDOWN_EXTENSIONS } from './constants.mjs';
import { P as PluggableList } from './index.d-3cc375e3.js';
import { Options } from 'rehype-pretty-code';

declare const searchSchema: z.ZodUnion<[z.ZodBoolean, z.ZodObject<{
    /**
     * Whether to index code blocks
     * @default true
     */
    codeblocks: z.ZodBoolean;
    /**
     * A filter function to filter out files from indexing, and return the
     * index file key, or null to skip indexing.
     * A site can have multiple indexes, by default they're separated by
     * locales as multiple index files.
     */
    indexKey: z.ZodOptional<z.ZodType<(filepath: string, route: string, locale?: string) => null | string, z.ZodTypeDef, (filepath: string, route: string, locale?: string) => null | string>>;
}, "strict", z.ZodTypeAny, {
    codeblocks: boolean;
    indexKey?: ((filepath: string, route: string, locale?: string) => null | string) | undefined;
}, {
    codeblocks: boolean;
    indexKey?: ((filepath: string, route: string, locale?: string) => null | string) | undefined;
}>]>;
type Transform = (result: string, options: {
    route: string;
}) => string | Promise<string>;
declare const nextraConfigSchema: z.ZodObject<{
    mdxOptions: z.ZodOptional<z.ZodObject<{
        rehypePlugins: z.ZodOptional<z.ZodType<PluggableList | null | undefined, z.ZodTypeDef, PluggableList | null | undefined>>;
        remarkPlugins: z.ZodOptional<z.ZodType<PluggableList | null | undefined, z.ZodTypeDef, PluggableList | null | undefined>>;
        format: z.ZodOptional<z.ZodEnum<["detect", "mdx", "md"]>>;
        rehypePrettyCodeOptions: z.ZodOptional<z.ZodType<Options, z.ZodTypeDef, Options>>;
    }, "strict", z.ZodTypeAny, {
        rehypePlugins?: PluggableList | null | undefined;
        remarkPlugins?: PluggableList | null | undefined;
        format?: "mdx" | "md" | "detect" | undefined;
        rehypePrettyCodeOptions?: Options | undefined;
    }, {
        rehypePlugins?: PluggableList | null | undefined;
        remarkPlugins?: PluggableList | null | undefined;
        format?: "mdx" | "md" | "detect" | undefined;
        rehypePrettyCodeOptions?: Options | undefined;
    }>>;
    themeConfig: z.ZodOptional<z.ZodString>;
    defaultShowCopyCode: z.ZodOptional<z.ZodBoolean>;
    search: z.ZodOptional<z.ZodUnion<[z.ZodBoolean, z.ZodObject<{
        /**
         * Whether to index code blocks
         * @default true
         */
        codeblocks: z.ZodBoolean;
        /**
         * A filter function to filter out files from indexing, and return the
         * index file key, or null to skip indexing.
         * A site can have multiple indexes, by default they're separated by
         * locales as multiple index files.
         */
        indexKey: z.ZodOptional<z.ZodType<(filepath: string, route: string, locale?: string) => null | string, z.ZodTypeDef, (filepath: string, route: string, locale?: string) => null | string>>;
    }, "strict", z.ZodTypeAny, {
        codeblocks: boolean;
        indexKey?: ((filepath: string, route: string, locale?: string) => null | string) | undefined;
    }, {
        codeblocks: boolean;
        indexKey?: ((filepath: string, route: string, locale?: string) => null | string) | undefined;
    }>]>>;
    staticImage: z.ZodOptional<z.ZodBoolean>;
    readingTime: z.ZodOptional<z.ZodBoolean>;
    latex: z.ZodOptional<z.ZodBoolean>;
    codeHighlight: z.ZodOptional<z.ZodBoolean>;
    transform: z.ZodOptional<z.ZodType<Transform, z.ZodTypeDef, Transform>>;
    transformPageOpts: z.ZodOptional<z.ZodType<(pageOpts: PageOpts) => PageOpts, z.ZodTypeDef, (pageOpts: PageOpts) => PageOpts>>;
    theme: z.ZodString;
}, "strict", z.ZodTypeAny, {
    theme: string;
    mdxOptions?: {
        rehypePlugins?: PluggableList | null | undefined;
        remarkPlugins?: PluggableList | null | undefined;
        format?: "mdx" | "md" | "detect" | undefined;
        rehypePrettyCodeOptions?: Options | undefined;
    } | undefined;
    themeConfig?: string | undefined;
    defaultShowCopyCode?: boolean | undefined;
    search?: boolean | {
        codeblocks: boolean;
        indexKey?: ((filepath: string, route: string, locale?: string) => null | string) | undefined;
    } | undefined;
    staticImage?: boolean | undefined;
    readingTime?: boolean | undefined;
    latex?: boolean | undefined;
    codeHighlight?: boolean | undefined;
    transform?: Transform | undefined;
    transformPageOpts?: ((pageOpts: PageOpts) => PageOpts) | undefined;
}, {
    theme: string;
    mdxOptions?: {
        rehypePlugins?: PluggableList | null | undefined;
        remarkPlugins?: PluggableList | null | undefined;
        format?: "mdx" | "md" | "detect" | undefined;
        rehypePrettyCodeOptions?: Options | undefined;
    } | undefined;
    themeConfig?: string | undefined;
    defaultShowCopyCode?: boolean | undefined;
    search?: boolean | {
        codeblocks: boolean;
        indexKey?: ((filepath: string, route: string, locale?: string) => null | string) | undefined;
    } | undefined;
    staticImage?: boolean | undefined;
    readingTime?: boolean | undefined;
    latex?: boolean | undefined;
    codeHighlight?: boolean | undefined;
    transform?: Transform | undefined;
    transformPageOpts?: ((pageOpts: PageOpts) => PageOpts) | undefined;
}>;
declare const pageThemeSchema: z.ZodObject<{
    breadcrumb: z.ZodBoolean;
    collapsed: z.ZodBoolean;
    footer: z.ZodBoolean;
    layout: z.ZodEnum<["default", "full", "raw"]>;
    navbar: z.ZodBoolean;
    pagination: z.ZodBoolean;
    sidebar: z.ZodBoolean;
    timestamp: z.ZodBoolean;
    toc: z.ZodBoolean;
    typesetting: z.ZodEnum<["default", "article"]>;
}, "strict", z.ZodTypeAny, {
    timestamp: boolean;
    breadcrumb: boolean;
    collapsed: boolean;
    footer: boolean;
    layout: "default" | "full" | "raw";
    navbar: boolean;
    pagination: boolean;
    sidebar: boolean;
    toc: boolean;
    typesetting: "default" | "article";
}, {
    timestamp: boolean;
    breadcrumb: boolean;
    collapsed: boolean;
    footer: boolean;
    layout: "default" | "full" | "raw";
    navbar: boolean;
    pagination: boolean;
    sidebar: boolean;
    toc: boolean;
    typesetting: "default" | "article";
}>;
/**
 * An option to control how an item should be displayed in the sidebar:
 * - `normal`: the default behavior, item will be displayed
 * - `hidden`: the item will not be displayed in the sidebar entirely
 * - `children`: if the item is a folder, itself will be hidden but all its children will still be processed
 */
declare const displaySchema: z.ZodEnum<["normal", "hidden", "children"]>;
declare const menuItemSchema: z.ZodObject<{
    display: z.ZodOptional<z.ZodEnum<["normal", "hidden", "children"]>>;
    items: z.ZodRecord<z.ZodString, z.ZodObject<{
        title: z.ZodString;
        href: z.ZodOptional<z.ZodString>;
        newWindow: z.ZodOptional<z.ZodBoolean>;
    }, "strict", z.ZodTypeAny, {
        title: string;
        href?: string | undefined;
        newWindow?: boolean | undefined;
    }, {
        title: string;
        href?: string | undefined;
        newWindow?: boolean | undefined;
    }>>;
    title: z.ZodString;
    type: z.ZodLiteral<"menu">;
}, "strict", z.ZodTypeAny, {
    type: "menu";
    title: string;
    items: Record<string, {
        title: string;
        href?: string | undefined;
        newWindow?: boolean | undefined;
    }>;
    display?: "children" | "normal" | "hidden" | undefined;
}, {
    type: "menu";
    title: string;
    items: Record<string, {
        title: string;
        href?: string | undefined;
        newWindow?: boolean | undefined;
    }>;
    display?: "children" | "normal" | "hidden" | undefined;
}>;
declare const metaSchema: z.ZodUnion<[z.ZodUnion<[z.ZodUnion<[z.ZodString, z.ZodObject<{
    display: z.ZodOptional<z.ZodEnum<["normal", "hidden", "children"]>>;
    items: z.ZodRecord<z.ZodString, z.ZodObject<{
        title: z.ZodString;
        href: z.ZodOptional<z.ZodString>;
        newWindow: z.ZodOptional<z.ZodBoolean>;
    }, "strict", z.ZodTypeAny, {
        title: string;
        href?: string | undefined;
        newWindow?: boolean | undefined;
    }, {
        title: string;
        href?: string | undefined;
        newWindow?: boolean | undefined;
    }>>;
    title: z.ZodString;
    type: z.ZodLiteral<"menu">;
}, "strict", z.ZodTypeAny, {
    type: "menu";
    title: string;
    items: Record<string, {
        title: string;
        href?: string | undefined;
        newWindow?: boolean | undefined;
    }>;
    display?: "children" | "normal" | "hidden" | undefined;
}, {
    type: "menu";
    title: string;
    items: Record<string, {
        title: string;
        href?: string | undefined;
        newWindow?: boolean | undefined;
    }>;
    display?: "children" | "normal" | "hidden" | undefined;
}>]>, z.ZodObject<{
    title: z.ZodString;
    type: z.ZodLiteral<"separator">;
}, "strict", z.ZodTypeAny, {
    type: "separator";
    title: string;
}, {
    type: "separator";
    title: string;
}>]>, z.ZodObject<{
    href: z.ZodOptional<z.ZodString>;
    newWindow: z.ZodOptional<z.ZodBoolean>;
    display: z.ZodOptional<z.ZodEnum<["normal", "hidden", "children"]>>;
    theme: z.ZodOptional<z.ZodObject<{
        breadcrumb: z.ZodOptional<z.ZodBoolean>;
        collapsed: z.ZodOptional<z.ZodBoolean>;
        footer: z.ZodOptional<z.ZodBoolean>;
        layout: z.ZodOptional<z.ZodEnum<["default", "full", "raw"]>>;
        navbar: z.ZodOptional<z.ZodBoolean>;
        pagination: z.ZodOptional<z.ZodBoolean>;
        sidebar: z.ZodOptional<z.ZodBoolean>;
        timestamp: z.ZodOptional<z.ZodBoolean>;
        toc: z.ZodOptional<z.ZodBoolean>;
        typesetting: z.ZodOptional<z.ZodEnum<["default", "article"]>>;
    }, "strict", z.ZodTypeAny, {
        breadcrumb?: boolean | undefined;
        collapsed?: boolean | undefined;
        footer?: boolean | undefined;
        layout?: "default" | "full" | "raw" | undefined;
        navbar?: boolean | undefined;
        pagination?: boolean | undefined;
        sidebar?: boolean | undefined;
        timestamp?: boolean | undefined;
        toc?: boolean | undefined;
        typesetting?: "default" | "article" | undefined;
    }, {
        breadcrumb?: boolean | undefined;
        collapsed?: boolean | undefined;
        footer?: boolean | undefined;
        layout?: "default" | "full" | "raw" | undefined;
        navbar?: boolean | undefined;
        pagination?: boolean | undefined;
        sidebar?: boolean | undefined;
        timestamp?: boolean | undefined;
        toc?: boolean | undefined;
        typesetting?: "default" | "article" | undefined;
    }>>;
    title: z.ZodOptional<z.ZodString>;
    type: z.ZodOptional<z.ZodEnum<["page", "doc"]>>;
}, "strict", z.ZodTypeAny, {
    href?: string | undefined;
    newWindow?: boolean | undefined;
    display?: "children" | "normal" | "hidden" | undefined;
    theme?: {
        breadcrumb?: boolean | undefined;
        collapsed?: boolean | undefined;
        footer?: boolean | undefined;
        layout?: "default" | "full" | "raw" | undefined;
        navbar?: boolean | undefined;
        pagination?: boolean | undefined;
        sidebar?: boolean | undefined;
        timestamp?: boolean | undefined;
        toc?: boolean | undefined;
        typesetting?: "default" | "article" | undefined;
    } | undefined;
    title?: string | undefined;
    type?: "page" | "doc" | undefined;
}, {
    href?: string | undefined;
    newWindow?: boolean | undefined;
    display?: "children" | "normal" | "hidden" | undefined;
    theme?: {
        breadcrumb?: boolean | undefined;
        collapsed?: boolean | undefined;
        footer?: boolean | undefined;
        layout?: "default" | "full" | "raw" | undefined;
        navbar?: boolean | undefined;
        pagination?: boolean | undefined;
        sidebar?: boolean | undefined;
        timestamp?: boolean | undefined;
        toc?: boolean | undefined;
        typesetting?: "default" | "article" | undefined;
    } | undefined;
    title?: string | undefined;
    type?: "page" | "doc" | undefined;
}>]>;

type MetaFilename = typeof META_FILENAME;
type MarkdownExtension = (typeof MARKDOWN_EXTENSIONS)[number];
interface LoaderOptions extends NextraConfig {
    isPageImport?: boolean;
    locales: string[];
}
interface Folder<FileType = PageMapItem> {
    kind: 'Folder';
    name: string;
    route: string;
    children: FileType[];
}
type MetaJsonFile = {
    kind: 'Meta';
    data: {
        [fileName: string]: Meta;
    };
    __nextra_src?: string;
};
type DynamicFolder = {
    type: 'folder';
    items: DynamicMeta;
    title?: string;
};
type DynamicMetaItem = Meta | DynamicFolder;
type DynamicMeta = Record<string, DynamicMetaItem>;
type DynamicMetaJsonFile = {
    kind: 'Meta';
    data: DynamicMeta;
};
type FrontMatter = GrayMatterFile<string>['data'];
type Meta = string | Record<string, any>;
type MdxFile<FrontMatterType = FrontMatter> = {
    kind: 'MdxPage';
    name: string;
    route: string;
    frontMatter?: FrontMatterType;
};
type MetaJsonPath = `${string}/${MetaFilename}`;
type MdxPath = `${string}.${MarkdownExtension}`;
type FileMap = {
    [jsonPath: MetaJsonPath]: MetaJsonFile;
    [mdxPath: MdxPath]: MdxFile;
};
type PageMapItem = Folder | MdxFile | MetaJsonFile;
type Page = (MdxFile | Folder<Page>) & {
    meta?: Exclude<Meta, string>;
};
type Heading = {
    depth: Heading$1['depth'];
    value: string;
    id: string;
};
type PageOpts<FrontMatterType = FrontMatter> = {
    filePath: string;
    frontMatter: FrontMatterType;
    pageMap: PageMapItem[];
    title: string;
    headings: Heading[];
    hasJsxInH1?: boolean;
    timestamp?: number;
    readingTime?: ReadingTime;
};
type ReadingTime = {
    text: string;
    minutes: number;
    time: number;
    words: number;
};
type Search = z.infer<typeof searchSchema>;
type NextraConfig = z.infer<typeof nextraConfigSchema>;
type Nextra = (nextraConfig: NextraConfig) => (nextConfig: NextConfig) => NextConfig;
type ThemeConfig = any | null;
type NextraThemeLayoutProps = {
    pageOpts: PageOpts;
    themeConfig: ThemeConfig;
    children: ReactNode;
};
type NextraInternalGlobal = typeof globalThis & {
    [NEXTRA_INTERNAL]: {
        pageMap: PageMapItem[];
        route: string;
        context: Record<string, {
            Content: FC;
            pageOpts: PageOpts;
        }>;
        refreshListeners: Record<string, (() => void)[]>;
        Layout: FC<NextraThemeLayoutProps>;
        themeConfig?: ThemeConfig;
    };
};
type DynamicMetaDescriptor = {
    metaFilePath: string;
    metaObjectKeyPath: string;
    metaParentKeyPath: string;
};
type StructurizedData = Record<string, string>;
type SearchData = {
    [route: string]: {
        title: string;
        data: StructurizedData;
    };
};

export { DynamicFolder as D, Folder as F, Heading as H, LoaderOptions as L, MetaJsonFile as M, Nextra as N, PageMapItem as P, ReadingTime as R, StructurizedData as S, ThemeConfig as T, DynamicMetaItem as a, DynamicMeta as b, DynamicMetaJsonFile as c, FrontMatter as d, Meta as e, MdxFile as f, MetaJsonPath as g, MdxPath as h, FileMap as i, Page as j, PageOpts as k, Search as l, NextraConfig as m, NextraThemeLayoutProps as n, NextraInternalGlobal as o, DynamicMetaDescriptor as p, SearchData as q, nextraConfigSchema as r, searchSchema as s, pageThemeSchema as t, displaySchema as u, menuItemSchema as v, metaSchema as w };
