// src/webpack-plugins/nextra.ts
import { join } from "path";
import pkg from "graceful-fs";
import { CHUNKS_DIR } from "../constants.mjs";
import { PAGES_DIR } from "../file-system.mjs";
import { getDynamicMeta } from "../page-map.mjs";
import { collectFiles } from "../plugin.mjs";
var fs = pkg.promises;
var NextraPlugin = class {
  constructor(config) {
    this.config = config;
  }
  apply(compiler) {
    const pluginName = this.constructor.name;
    const { locales } = this.config;
    compiler.hooks.beforeCompile.tapAsync(pluginName, async (_, callback) => {
      try {
        const result = await collectFiles({ dir: PAGES_DIR });
        for (const locale of locales) {
          const folderItem = locale === "" ? { children: result.items } : result.items.find(
            (item) => "name" in item && item.name === locale
          );
          if (!folderItem)
            continue;
          await fs.mkdir(join(CHUNKS_DIR), { recursive: true });
          const [dynamicMetaItems, filteredItems] = getDynamicMeta(
            "",
            folderItem.children
          );
          const dynamicMetaImports = [];
          const dynamicMetaFunctions = [];
          for (const [
            index,
            { metaFilePath, ...descriptor }
          ] of dynamicMetaItems.entries()) {
            dynamicMetaImports.push(
              `import dynamicMeta${index} from '${metaFilePath}'`
            );
            dynamicMetaFunctions.push(
              `[dynamicMeta${index}, ${JSON.stringify(descriptor)}]`
            );
          }
          await fs.writeFile(
            join(CHUNKS_DIR, `nextra-page-map-${locale}.mjs`),
            `${dynamicMetaImports.join("\n")}

export const dynamicMetaModules = [${dynamicMetaFunctions.join(",")}]

export const pageMap = ${JSON.stringify(filteredItems)}`
          );
        }
        await fs.writeFile(
          join(CHUNKS_DIR, "nextra-file-map.mjs"),
          `export const fileMap = ${JSON.stringify(result.fileMap)}`
        );
        callback();
      } catch (error) {
        callback(error);
      }
    });
  }
};
export {
  NextraPlugin
};
